/*
 * Copyright (C) 2012-2013 jeanfi@gmail.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA
 */

#include <webkit/webkit.h>

#include "webbrowser.h"

static WebKitWebView *view;
static GtkLabel *w_status;

static gboolean new_window_requested_cbk(WebKitWebView *view,
					 WebKitWebFrame *frame,
					 WebKitNetworkRequest *rq,
					 WebKitWebNavigationAction *action,
					 WebKitWebPolicyDecision *decision)
{
	webkit_web_view_load_uri(view, webkit_network_request_get_uri(rq));

	webkit_web_policy_decision_ignore(decision);

	return TRUE;
}

static void hovering_over_link_cbk(WebKitWebView *web_view,
				   gchar *title,
				   gchar *uri,
				   gpointer user_data)
{
	if (uri)
		gtk_label_set_label(w_status, uri);
	else
		gtk_label_set_label(w_status, "");
}

GtkWidget *web_get_widget()
{
	if (!view) {
		view = WEBKIT_WEB_VIEW(webkit_web_view_new());
		g_signal_connect(view,
				 "new-window-policy-decision-requested",
				 G_CALLBACK(new_window_requested_cbk),
				 view);
		g_signal_connect(view,
				 "hovering-over-link",
				 G_CALLBACK(hovering_over_link_cbk),
				 NULL);
	}

	return GTK_WIDGET(view);
}

void web_load(const char *str)
{
	webkit_web_view_load_string(view, str, NULL, "UTF-8", "file://");
}

void webbrowser_init(GtkLabel *status)
{
	w_status = status;
}
